#!/usr/bin/env python

from distutils.core import setup
import os
import glob

name = "python-UnixSocketTransport"
version = "0.0.1"

setup(name=name,
	version=version,
	description="An UNIX sockets transport library for XML-RPC",
	long_description="UnixSocketTransport is a specialized transport for XML-RPC/HTTP over UNIX sockets instead of TCP/IP",
	author="Manuel Amador (Rudd-O)",
	author_email="rudd-o@amautacorp.com",
	url="http://www.amautacorp.com/staff/Rudd-O/projects/search-services/",
	py_modules=["UnixSocketTransport"],
	)
